Summary:   Coova-Chilli is a Wireless LAN Access Point Controller
Name:      coova-chilli
Version:   1.6
Release:   1%{?dist}
URL:       http://coova.github.io/
Source0:   %{name}-%{version}.tar.gz
Source111: coova-chilli-sysconfig
Source112: coova-chilli-ipup.sh
Patch1:    coova-chilli-git20220319.patch
Patch100:  coova-chilli-init.patch
# Don't use it any more, use the ipup.sh script
Patch101:  coova-chilli-up.patch
%if 0%{?rhel} <= 7
Patch200:  coova-chilli-libjson.lux.patch
%endif
Patch201:  coova-chilli-chillicontroller_ip.patch
Patch202:  coova-chilli-1.6-INITDIR.lux.patch
License:   GPL
Group:     System Environment/Daemons

# Needed for sh bootstrap, build phase
BuildRequires: autoconf automake libtool

%if %{!?_without_ssl:1}0
BuildRequires: openssl-devel libtool gengetopt
%endif

# Require haserl since the internal captive portal uses it, like all other CPs for chilli I'm aware of at the moment.
Requires: haserl

%if 0%{?rhel} >= 7
# In RH7, json-c is in a stock rpm
Requires: json-c
BuildRequires: json-c-devel
%endif

%description

Coova-Chilli is a fork of the ChilliSpot project - an open source captive
portal or wireless LAN access point controller. It supports web based login
(Universal Access Method, or UAM), standard for public HotSpots, and it
supports Wireless Protected Access (WPA), the standard for secure roamable
networks. Authentication, Authorization and Accounting (AAA) is handled by
your favorite radius server. Read more at http://coova.github.io/.

%prep
%setup
%patch1 -p1
%patch100 -p1
#%patch101 -p1
%if 0%{?rhel} <= 7
%patch200 -p1
%endif
%patch201 -p1
%patch202 -p1
%if 0%{?rhel} >= 8
sed -i '1s:/usr/bin/python:/usr/bin/python3:' conf/CoovaChilliLib.py.in
%endif

%build
sh bootstrap
%configure \
        --disable-static \
        --enable-shared \
	--enable-largelimits \
	--enable-miniportal \
	--enable-chilliredir \
	--enable-chilliproxy \
        --enable-chilliscript \
	--enable-ipwhitelist \
	--with-poll \
%if 0%{?rhel} >= 7
    --with-json \
    --enable-json \
%else
    --enable-libjson \
%endif
%if %{!?_without_ssl:1}0
	--with-openssl \
	--enable-chilliradsec \
%endif


make

%install
make install DESTDIR=$RPM_BUILD_ROOT

rm -rf $RPM_BUILD_ROOT%{_prefix}/include/*
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
#cp -f chilli $RPM_BUILD_ROOT%{_sysconfdir}/init.d/chilli

# Place a default config file to be edited by the admin
cp -p $RPM_BUILD_ROOT%{_sysconfdir}/chilli/defaults $RPM_BUILD_ROOT%{_sysconfdir}/chilli/config
# throw away the initial comments telling to copy the defaults to config
perl -ni -e '1 .. /^\s*$/ and /^#/ or print' $RPM_BUILD_ROOT%{_sysconfdir}/chilli/config
perl -ni -e '1 ... /^\S/ and /^\s*$/ or print' $RPM_BUILD_ROOT%{_sysconfdir}/chilli/config

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
cp %{SOURCE111} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/chilli
cp %{SOURCE112} $RPM_BUILD_ROOT%{_sysconfdir}/chilli/ipup.sh

%check
rm -f $RPM_BUILD_ROOT%{_libdir}/python/*.pyc
rm -f $RPM_BUILD_ROOT%{_libdir}/python/*.pyo

%clean
rm -rf $RPM_BUILD_ROOT
make clean

%post
/sbin/chkconfig --add chilli

%preun
if [ $1 = 0 ]; then
        /sbin/service chilli stop > /dev/null 2>&1
        /sbin/chkconfig --del chilli
fi

%files
%defattr(-,root,root)
%{_sbindir}/*
%{_libdir}/*.so*
%{_libdir}/python/CoovaChilliLib.py
%{_sysconfdir}/init.d/chilli
%doc AUTHORS COPYING ChangeLog INSTALL README doc/dictionary.coovachilli doc/hotspotlogin.cgi
%doc doc/fmttxt.pl doc/attributes doc/chilli.conf doc/firewall.* doc/freeradius.users doc/hotspotlogin* doc/*.php
%config %{_sysconfdir}/chilli.conf
%config %{_sysconfdir}/chilli/gui-config-default.ini
%config(noreplace) %{_sysconfdir}/chilli/defaults
%config(noreplace) %{_sysconfdir}/chilli/config
%dir %{_sysconfdir}/chilli
%dir %{_sysconfdir}/chilli/www
%config(noreplace) %attr(755,root,root)%{_sysconfdir}/chilli/www/config.sh
%config(noreplace) %{_sysconfdir}/sysconfig/chilli
%attr(4750,root,root)%{_sbindir}/chilli_script
%config(noreplace) %{_sysconfdir}/chilli/www/*
%{_sysconfdir}/chilli/wwwsh
%config(noreplace) %{_sysconfdir}/chilli/functions
%config(noreplace) %{_sysconfdir}/chilli/*.sh
%config(noreplace) %{_sysconfdir}/chilli/wpad.dat
%{_mandir}/man1/*.1*
%{_mandir}/man5/*.5*
%{_mandir}/man8/*.8*

%changelog
* Fri Jun 26 2015 Giovanni Bezicheri <giovanni.bezicheri@nethesis.it>
* Fix json encoding for radius reply.

* Tue May 13 2015 Giovanni Bezicheri <giovanni.bezicheri@nethesis.it>
* Add support for json uri.

* Fri Nov 14 2014 Giovanni Bezicheri <giovanni.bezicheri@nethesis.it>
- Add HS_LANIF_KEEPADDR option in chilli sysconfig.

* Thu Jul 10 2014 Giovanni Bezicheri <giovanni.bezicheri@nethesis.it>
- 1.3.1 release for NethServer. See ChangeLog.

* Sat Jan 2 2010 <david@coova.com>
- 1.2.0 release
* Thu Sep 30 2007 <david@coova.com>
- 1.0.8 release 
* Thu Aug 20 2007 <david@coova.com>
- 1.0-coova.7 release
* Thu Jun 7 2007 <david@coova.com>
- 1.0-coova.6 release
* Wed May 16 2007  <david@coova.com>
- 1.0-coova.5 release
* Wed Feb 07 2007  <david@coova.com>
- 1.0-coova.4 release
* Wed Nov 15 2006  <david@coova.com>
- 1.0-coova.3 release
* Thu Mar 25 2004  <support@chillispot.org>
- Initial release.
